<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'سخنگاه اسپيپ (خصوصي همگاني)؟',
	'forum_slogan' => 'مديريت سخنگاه‌هاي خصوصي و همگاني در اسپيپ',
];
